@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-default-font-presets
-;; Package-Version: 20251126.350
-;; Package-Revision: 0ac18ca47b80
+;; Package-Version: 20251214.1133
+;; Package-Revision: 6d69a989409b
 ;; Package-Requires: ((emacs "26.1"))
 
 ;;; Commentary:
@@ -17,7 +17,7 @@
 ;; To bind keys to next/previous font.
 ;;
 
-;;; Usage
+;;; Usage:
 
 ;; Example:
 ;;
@@ -78,7 +78,7 @@ Otherwise each preset remembers the last scale set."
 ;; ---------------------------------------------------------------------------
 ;; Internal Variables
 
-;; The index of the font in `default-font-presets--index',
+;; The index of the font in `default-font-presets-list',
 ;; initialized on first use.
 (defvar default-font-presets--index nil)
 (defvar default-font-presets--scale-delta 0)
@@ -144,7 +144,7 @@ Otherwise each preset remembers the last scale set."
 
 (defun default-font-presets--split (font-name)
   "Simply split FONT-NAME that might be used for XFT properties.
-For example: `A:B` is converted to (`A` `:B`)."
+For example: \"A:B\" is converted to (\"A\" \":B\")."
   (declare (important-return-value t))
   (let ((sep (string-match-p ":" font-name)))
     (cond
@@ -218,7 +218,7 @@ and TAIL is any trailing part after the size."
        nil))
 
     ;; Update the default font for new windows.
-    (let ((cell (assoc 'font default-frame-alist 'eq)))
+    (let ((cell (assoc 'font default-frame-alist #'eq)))
       (when cell
         (setcdr cell current-font)))
 
@@ -244,7 +244,7 @@ and TAIL is any trailing part after the size."
     (default-font-presets--font-update current-font)))
 
 (defun default-font-presets--index-ensure (font-name font-name-no-attrs)
-  "Add FONT-NAME list or return index if it's not already there.
+  "Add FONT-NAME to the list if not present, returning its index.
 
 Argument FONT-NAME-NO-ATTRS is simply to avoid re-calculating the value."
   (declare (important-return-value t))
@@ -262,7 +262,7 @@ Argument FONT-NAME-NO-ATTRS is simply to avoid re-calculating the value."
 (defun default-font-presets--init ()
   "Initialize `default-font-presets--index'.
 
-This adds to `default-font-presets-list' or replacing one of it's values
+This adds to `default-font-presets-list' or replacing one of its values
 when the default font is already in the list.
 
 Replacement is done so any fine tuning to the default font is kept,
@@ -316,7 +316,7 @@ Return non-nil when the scale changed."
 
         ;; Important *not* to adjust the frame while calculating a new font size.
         ;; Needed when the window is floating, but harmless none the less.
-        ;; TODO: preform a refresh on all frames if `window-resize-pixel-wise' isn't supported.
+        ;; TODO: perform a refresh on all frames if `window-resize-pixel-wise' isn't supported.
         (frame-inhibit-implied-resize t)
 
         ;; Don't redraw while resizing.
